"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSettingsCreateValidation = void 0;
var _zod = _interopRequireDefault(require("zod"));
var _trimEnd = _interopRequireDefault(require("lodash/trimEnd"));
var _utils = require("@webiny/utils");
// We don't want trailing slashes in Page Builder app's important URLs (website URL, website preview URL, app URL).
const trimTrailingSlashes = value => (0, _trimEnd.default)(value, "/");
const createSettingsCreateValidation = () => {
  return _zod.default.object({
    name: _zod.default.string().max(500).optional(),
    websiteUrl: _zod.default.union([_zod.default.string().max(500).url(), _zod.default.string().nullish().optional()]).nullish().optional().transform(value => {
      if (!value) {
        return value || "";
      }
      return trimTrailingSlashes(value);
    }).optional(),
    websitePreviewUrl: _zod.default.union([_zod.default.string().max(500).url(), _zod.default.string().nullish().optional()]).nullish().optional().transform(value => {
      if (!value) {
        return value || "";
      }
      return trimTrailingSlashes(value);
    }),
    favicon: _zod.default.object({
      id: _zod.default.string().nullish().optional().transform(value => value || undefined),
      src: _zod.default.string().nullish().optional().transform(value => value || undefined)
    }).passthrough().nullish().optional().transform(value => {
      return value || undefined;
    }),
    logo: _zod.default.object({
      id: _zod.default.string().nullish().optional().transform(value => value || undefined),
      src: _zod.default.string().nullish().optional().transform(value => value || undefined)
    }).passthrough().nullish().optional().transform(value => value || undefined),
    social: _zod.default.object({
      facebook: _zod.default.string().url().max(500).nullish().optional().transform(value => value || undefined),
      twitter: _zod.default.string().url().max(500).nullish().optional().transform(value => value || undefined),
      instagram: _zod.default.string().url().max(500).nullish().optional().transform(value => value || undefined),
      linkedIn: _zod.default.string().url().max(500).nullish().optional().transform(value => value || undefined),
      image: _zod.default.object({
        id: _zod.default.string().optional(),
        src: _zod.default.string().optional()
      }).passthrough().nullish().optional().transform(value => value || undefined)
    }).passthrough().nullish().default({}).optional().transform(value => value || undefined),
    htmlTags: _zod.default.object({
      header: _zod.default.string().nullish().optional().transform(value => value || undefined),
      footer: _zod.default.string().nullish().optional().transform(value => value || undefined)
    }).passthrough().nullish().optional().transform(value => value || undefined),
    pages: _zod.default.object({
      home: _zod.default.string().nullish().optional().transform(value => {
        if (!value) {
          return value;
        }
        const {
          id
        } = (0, _utils.parseIdentifier)(value);
        return id;
      }),
      notFound: _zod.default.string().nullish().optional().transform(value => {
        if (!value) {
          return value;
        }
        const {
          id
        } = (0, _utils.parseIdentifier)(value);
        return id;
      })
    }).passthrough().nullish().optional().transform(value => value || undefined)
  }).partial().passthrough();
};
exports.createSettingsCreateValidation = createSettingsCreateValidation;

//# sourceMappingURL=validation.js.map